package controller

import (
	"electricity_bill_calc/excel"
	"electricity_bill_calc/response"
	"electricity_bill_calc/security"
	"electricity_bill_calc/service"
	"net/http"
	"strconv"

	"github.com/gin-gonic/gin"
)

func InitializeEndUserController(router *gin.Engine) {
	router.GET("/report/:rid/submeter", security.EnterpriseAuthorize, fetchEndUserInReport)
	router.GET("/report/:rid/meter/template", security.EnterpriseAuthorize, downloadEndUserRegisterTemplate)
}

func fetchEndUserInReport(c *gin.Context) {
	result := response.NewResult(c)
	requestReportId := c.Param("rid")
	if !ensureReportBelongs(c, result, requestReportId) {
		return
	}
	keyword := c.DefaultQuery("keyword", "")
	requestPage, err := strconv.Atoi(c.DefaultQuery("page", "1"))
	if err != nil {
		result.NotAccept("查询参数[page]格式不正确。")
		return
	}
	endUsers, totalItem, err := service.EndUserService.SearchEndUserRecord(requestReportId, keyword, requestPage)
	if err != nil {
		result.NotFound(err.Error())
		return
	}
	result.Json(
		http.StatusOK,
		"已获取到符合条件的终端用户集合",
		response.NewPagedResponse(requestPage, totalItem).ToMap(),
		gin.H{"meters": endUsers},
	)
}

func downloadEndUserRegisterTemplate(c *gin.Context) {
	result := response.NewResult(c)
	requestReportId := c.Param("rid")
	if !ensureReportBelongs(c, result, requestReportId) {
		return
	}
	users, err := service.EndUserService.AllEndUserRecord(requestReportId)
	if err != nil {
		result.NotFound(err.Error())
		return
	}
	gen := excel.NewMeterPVExcelTemplateGenerator()
	defer gen.Close()
	gen.WriteMeterData(users)
	c.Status(http.StatusOK)
	c.Header("Content-Type", "application/octet-stream")
	c.Header("Content-Transfer-Encoding", "binary")
	c.Header("Content-Disposition", "attachment; filename=抄表记录.xslx")
	gen.WriteTo(c.Writer)
}
